import { createDecorator } from 'vue-class-component';
export function Persist(options) {
    if (options === void 0) { options = {}; }
    return createDecorator(function (opts, k) {
        var name = (opts.name || '_').toLowerCase();
        var _a = options.key, key = _a === void 0 ? name + "_" + k : _a, expiryString = options.expiry, _b = options.immediate, immediate = _b === void 0 ? false : _b, _c = options.deep, deep = _c === void 0 ? true : _c;
        opts.mixins = (opts.mixins || []).concat([
            {
                mounted: function () {
                    var item = localStorage.getItem(key);
                    if (item) {
                        try {
                            var data = JSON.parse(item);
                            if (!data.expiry || new Date(data.expiry).getTime() - Date.now() > 0)
                                this[k] = data.value;
                        }
                        catch (e) {
                            console.log(e);
                        }
                    }
                    this.$watch(k, function (value) {
                        var persist = { value: value };
                        if (expiryString)
                            persist.expiry = parseRelativeTime(expiryString);
                        localStorage.setItem(key, JSON.stringify(persist));
                    }, { immediate: immediate, deep: deep });
                },
            },
        ]);
    });
}
export function parseRelativeTime(dateString) {
    var epoch = Date.now();
    var dateArray = dateString.split(/([a-zA-Z]+)/);
    if (isNaN(+dateArray[0]))
        throw new Error('Failed to parse time.');
    var input = Math.round(+dateArray[0]);
    var extensions = {
        ms: 1,
        s: 1000,
        m: 1000 * 60,
        h: 1000 * 60 * 60,
        d: 1000 * 60 * 60 * 24,
    };
    var multiplier = extensions[dateArray[1]] || extensions.h;
    return epoch + input * multiplier;
}
